@@ -67,7 +67,7 @@ class Workspace():
             self.directory,
             self.baseurl,
             self.mets.file_groups,
-            [str(f) for f in self.mets.find_files()],
+            [str(f) for f in self.mets.find_all_files()],
         )
 
     def reload_mets(self):
@@ -265,8 +265,7 @@ class Workspace():
         Return
             :class:`OcrdExif`
         """
-        files = self.mets.find_files(url=image_url)
-        f = files[0] if files else OcrdFile(None, url=image_url)
+        f = next(self.mets.find_files(url=image_url), OcrdFile(None, url=image_url))
         image_filename = self.download_file(f).local_filename
         with Image.open(image_filename) as pil_img:
             ocrd_exif = OcrdExif(pil_img)
@@ -288,8 +287,7 @@ class Workspace():
 
         """
         log = getLogger('ocrd.workspace._resolve_image_as_pil')
-        files = self.mets.find_files(url=image_url)
-        f = files[0] if files else OcrdFile(None, url=image_url)
+        f = next(self.mets.find_files(url=image_url), OcrdFile(None, url=image_url))
         image_filename = self.download_file(f).local_filename
 
         with pushd_popd(self.directory):
